@@ -95,6 +95,55 @@ TEAM_TRANSLATE = {'MER': 'mercedes', 'FER': 'ferrari',
                   'HAA': 'haas', 'WIL': 'williams'}
 """Mapping of team names to theirs respective abbreviations."""
 
+DRIVER_COLORS = {
+        "valtteri bottas": "#900000",
+        "zhou guanyu": "#500000",
+
+        "pierre gasly": "#2b4562",
+        "yuki tsunoda": "#356cac",
+
+        "fernando alonso": "#0090ff",
+        "esteban ocon": "#70c2ff",
+
+        "sebastian vettel": "#006f62",
+        "lance stroll": "#25a617",
+        "nico hulkenberg": "#2f9b90",
+
+        "charles leclerc": "#dc0000",
+        "carlos sainz": "#ff8181",
+
+        "kevin magnussen": "#ffffff",
+        "mick schumacher": "#cacaca",
+
+        "daniel ricciardo": "#ff8700",
+        "lando norris": "#eeb370",
+
+        "lewis hamilton": "#00d2be",
+        "george russell": "#24ffff",
+
+        "max verstappen": "#0600ef",
+        "sergio perez": "#716de2",
+
+        "alexander albon": "#005aff",
+        "nicholas latifi": "#012564",
+    }
+"""Mapping of driver colors (hex color code) to driver names.
+(current season only)"""
+
+
+DRIVER_TRANSLATE = {'LEC': 'charles leclerc', 'SAI': 'carlos sainz',
+                    'VER': 'max verstappen', 'SER': 'sergio perez',
+                    'RIC': 'daniel ricciardo', 'NOR': 'lando norris',
+                    'ALO': 'fernando alonso', 'OCO': 'esteban ocon',
+                    'BOT': 'valtteri bottas', 'ZHO': 'zhou guanyu',
+                    'GAS': 'pierre gasly', 'TSU': 'yuki tsunoda',
+                    'MAG': 'kevin magnussen', 'MSC': 'mick schumacher',
+                    'VET': 'sebastian vettel', 'HUL': 'nico hulkenberg',
+                    'STR': 'lance stroll',
+                    'HAM': 'lewis hamilton', 'RUS': 'george russell',
+                    'ALB': 'alexander albon', 'LAT': 'nicholas latifi'}
+"""Mapping of driver names to theirs respective abbreviations."""
+
 COLOR_PALETTE = ['#FF79C6', '#50FA7B', '#8BE9FD', '#BD93F9',
                  '#FFB86C', '#FF5555', '#F1FA8C']
 """The default color palette for matplotlib plot lines in fastf1's color
@@ -139,6 +188,73 @@ def setup_mpl(mpl_timedelta_support=True, color_scheme='fastf1',
         _enable_misc_mpl_mods()
 
 
+def driver_color(identifier):
+    """Get a driver's color from a driver name or abbreviation.
+
+    This function will try to find a matching driver for any identifier string
+    that is passed to it. This involves case insensitive matching and partial
+    string matching.
+
+    If you want exact string matching, you should use the
+    :any:`DRIVER_COLORS` dictionary directly, using :any:`DRIVER_TRANSLATE` to
+    convert abbreviations to team names if necessary.
+
+    Example::
+
+        >>> driver_color('charles leclerc')
+        '#dc0000'
+        >>> driver_color('max verstappen')
+        '#0600ef'
+        >>> driver_color('ver')
+        '#0600ef'
+        >>> driver_color('lec')
+        '#dc0000'
+
+        shortened driver names and typos can be dealt with
+        too (within reason)
+
+        >>> driver_color('Max Verst')
+        '#0600ef'
+        >>> driver_color('Charles')
+        '#dc0000'
+
+    Args:
+        identifier (str): Abbreviation or uniquely identifying name of the driver.
+
+    Returns:
+        str: hex color code
+    """
+
+    if identifier.upper() in DRIVER_TRANSLATE:
+        # try short team abbreviations first
+        return DRIVER_COLORS[DRIVER_TRANSLATE[identifier.upper()]]
+    else:
+        identifier = identifier.lower()
+
+        # check for an exact team name match
+        if identifier in DRIVER_COLORS:
+            return DRIVER_COLORS[identifier]
+
+        # check for exact partial string match
+        for team_name, color in DRIVER_COLORS.items():
+            if identifier in team_name:
+                return color
+
+        # do fuzzy string matching
+        key_ratios = list()
+        for existing_key in DRIVER_COLORS.keys():
+            ratio = fuzz.ratio(identifier, existing_key)
+            key_ratios.append((ratio, existing_key))
+        key_ratios.sort(reverse=True)
+        if (key_ratios[0][0] < 35) or (key_ratios[0][0]/key_ratios[1][0] < 1.2):
+            # ensure that the best match has a minimum accuracy (35 out of
+            # 100) and that it has a minimum confidence (at least 20% better
+            # than second best)
+            raise KeyError
+        best_matched_key = key_ratios[0][1]
+        return DRIVER_COLORS[best_matched_key]
+
+
 def team_color(identifier):
     """Get a team's color from a team name or abbreviation.
 
